==> ejc-assistrmat-impl-3.0.0-20220322.020504-1-sources.jar: com/ejianc/business/assist/rmat/bean/RestituteScrapEntity.java <==
package com.ejianc.business.assist.rmat.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 退赔单报废清单明细
 * 
 * @author generator
 * 
 */
 @TableName("ejc_prormat_restitute_scrap")
public class RestituteScrapEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="material_id")
    private Long materialId; // 物料主键
    @TableField(value="material_name")
    private String materialName; // 物料名称
    @TableField(value="material_type_id")
    private Long materialTypeId; // 物料分类
    @TableField(value="material_type_name")
    private String materialTypeName; // 物料分类名称
    @TableField(value="material_code")
    private String materialCode; // 物料编码
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="unit_name")
    private String unitName; // 计量单位
    @TableField(value="damage_num")
    private BigDecimal damageNum; // 报废数量
    @TableField(value="sum_mny")
    private BigDecimal sumMny; // 损坏赔偿金额计算
    @TableField(value="damage_name")
    private String damageName; // 损坏赔偿名称
    @TableField(value="damage_unit")
    private String damageUnit; // 损坏赔偿单位
    @TableField(value="damage_tax_price")
    private BigDecimal damageTaxPrice; // 损坏赔偿单价
    @TableField(value="damage_price")
    private BigDecimal damagePrice; // 损坏赔偿单价(无税)
    @TableField(value="tax_rate")
    private BigDecimal taxRate; // 税率
    @TableField(value="mny")
    private BigDecimal mny; // 本次损坏赔偿金额(无税)
    @TableField(value="tax_mny")
    private BigDecimal taxMny; // 本次损坏赔偿金额
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="restitute_id")
    private Long restituteId; // 退赔单主键
    @TableField(value="unit_id")
    private Long unitId; // 单位主键
    @TableField(value="tax")
    private BigDecimal tax; // 损坏赔偿税额
    @TableField(value="sum_tax_mny")
    private BigDecimal sumTaxMny; // 损坏赔偿金额计算(含税)
    
    
    

    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public BigDecimal getDamageNum() {
        return damageNum;
    }

    public void setDamageNum(BigDecimal damageNum) {
        this.damageNum = damageNum;
    }
    public BigDecimal getSumMny() {
        return sumMny;
    }

    public void setSumMny(BigDecimal sumMny) {
        this.sumMny = sumMny;
    }
    public String getDamageName() {
        return damageName;
    }

    public void setDamageName(String damageName) {
        this.damageName = damageName;
    }
    public String getDamageUnit() {
        return damageUnit;
    }

    public void setDamageUnit(String damageUnit) {
        this.damageUnit = damageUnit;
    }
    public BigDecimal getDamagePrice() {
        return damagePrice;
    }

    public void setDamagePrice(BigDecimal damagePrice) {
        this.damagePrice = damagePrice;
    }
    public BigDecimal getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(BigDecimal taxRate) {
        this.taxRate = taxRate;
    }
    public BigDecimal getMny() {
        return mny;
    }

    public void setMny(BigDecimal mny) {
        this.mny = mny;
    }
    public BigDecimal getTaxMny() {
        return taxMny;
    }

    public void setTaxMny(BigDecimal taxMny) {
        this.taxMny = taxMny;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getRestituteId() {
        return restituteId;
    }

    public void setRestituteId(Long restituteId) {
        this.restituteId = restituteId;
    }
    public Long getUnitId() {
        return unitId;
    }

    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }
    public BigDecimal getTax() {
        return tax;
    }

    public void setTax(BigDecimal tax) {
        this.tax = tax;
    }
    public BigDecimal getSumTaxMny() {
        return sumTaxMny;
    }

    public void setSumTaxMny(BigDecimal sumTaxMny) {
        this.sumTaxMny = sumTaxMny;
    }

    public BigDecimal getDamageTaxPrice() {
        return damageTaxPrice;
    }

    public void setDamageTaxPrice(BigDecimal damageTaxPrice) {
        this.damageTaxPrice = damageTaxPrice;
    }
}

==> ejc-assistrmat-impl-3.0.0-20220506.083930-83-sources.jar: com/ejianc/business/assist/rmat/bean/RestituteScrapEntity.java <==
package com.ejianc.business.assist.rmat.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 退赔单报废清单明细
 * 
 * @author generator
 * 
 */
 @TableName("ejc_assistrmat_restitute_scrap")
public class RestituteScrapEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="material_id")
    private Long materialId; // 物料主键
    @TableField(value="material_name")
    private String materialName; // 物料名称
    @TableField(value="material_type_id")
    private Long materialTypeId; // 物料分类
    @TableField(value="material_type_name")
    private String materialTypeName; // 物料分类名称
    @TableField(value="material_code")
    private String materialCode; // 物料编码
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="unit_name")
    private String unitName; // 计量单位
    @TableField(value="damage_num")
    private BigDecimal damageNum; // 报废数量
    @TableField(value="sum_mny")
    private BigDecimal sumMny; // 损坏赔偿金额计算
    @TableField(value="damage_name")
    private String damageName; // 损坏赔偿名称
    @TableField(value="damage_unit")
    private String damageUnit; // 损坏赔偿单位
    @TableField(value="damage_tax_price")
    private BigDecimal damageTaxPrice; // 损坏赔偿单价
    @TableField(value="damage_price")
    private BigDecimal damagePrice; // 损坏赔偿单价(无税)
    @TableField(value="tax_rate")
    private BigDecimal taxRate; // 税率
    @TableField(value="mny")
    private BigDecimal mny; // 本次损坏赔偿金额(无税)
    @TableField(value="tax_mny")
    private BigDecimal taxMny; // 本次损坏赔偿金额
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="restitute_id")
    private Long restituteId; // 退赔单主键
    @TableField(value="unit_id")
    private Long unitId; // 单位主键
    @TableField(value="tax")
    private BigDecimal tax; // 损坏赔偿税额
    @TableField(value="sum_tax_mny")
    private BigDecimal sumTaxMny; // 损坏赔偿金额计算(含税)
    
    
    

    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public BigDecimal getDamageNum() {
        return damageNum;
    }

    public void setDamageNum(BigDecimal damageNum) {
        this.damageNum = damageNum;
    }
    public BigDecimal getSumMny() {
        return sumMny;
    }

    public void setSumMny(BigDecimal sumMny) {
        this.sumMny = sumMny;
    }
    public String getDamageName() {
        return damageName;
    }

    public void setDamageName(String damageName) {
        this.damageName = damageName;
    }
    public String getDamageUnit() {
        return damageUnit;
    }

    public void setDamageUnit(String damageUnit) {
        this.damageUnit = damageUnit;
    }
    public BigDecimal getDamagePrice() {
        return damagePrice;
    }

    public void setDamagePrice(BigDecimal damagePrice) {
        this.damagePrice = damagePrice;
    }
    public BigDecimal getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(BigDecimal taxRate) {
        this.taxRate = taxRate;
    }
    public BigDecimal getMny() {
        return mny;
    }

    public void setMny(BigDecimal mny) {
        this.mny = mny;
    }
    public BigDecimal getTaxMny() {
        return taxMny;
    }

    public void setTaxMny(BigDecimal taxMny) {
        this.taxMny = taxMny;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getRestituteId() {
        return restituteId;
    }

    public void setRestituteId(Long restituteId) {
        this.restituteId = restituteId;
    }
    public Long getUnitId() {
        return unitId;
    }

    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }
    public BigDecimal getTax() {
        return tax;
    }

    public void setTax(BigDecimal tax) {
        this.tax = tax;
    }
    public BigDecimal getSumTaxMny() {
        return sumTaxMny;
    }

    public void setSumTaxMny(BigDecimal sumTaxMny) {
        this.sumTaxMny = sumTaxMny;
    }

    public BigDecimal getDamageTaxPrice() {
        return damageTaxPrice;
    }

    public void setDamageTaxPrice(BigDecimal damageTaxPrice) {
        this.damageTaxPrice = damageTaxPrice;
    }
}
